# (akien) The Vulkan SDK requires some care when updating.
# We only package SDK releases (sdk-%%{version}).
#
# There are many interdependent dependencies which need to be synced to specific
# "known good" commits for the APIs to be compatible.
#
# Upstream is now properly tagging `sdk-*` versions on each component, so the
# instructions below have been simplified.
# Find the latest SDK release by reviewing GitHub tags for e.g. Vulkan-Headers.
#
# Here's the build order.
# - A1 and A2 can be done in parallel.
# - 2. means that you should wait for 1. to finish, while 1.a. and 1.b. means
#   that both can be pushed in parallel.
#
# (A1) SPIRV stack:
# 1. spirv-headers
# 2. spirv-tools
# 3. glslang
#
# (A2) Vulkan stack:
# 1. vulkan-headers
# 2. vulkan-loader
#
# (B) Depends on A1 and A2 being completed:
# 1.a. vulkan-tools
# 1.b. vulkan-validation-layers
# 1.c. vkd3d

%define __python %{__python3}

%define uname   Vulkan-Headers

Name:           vulkan-headers
Version:        1.3.231.1
Release:        %mkrel 1
Summary:        Vulkan header files and API registry
Group:          Development/C
License:        ASL 2.0
URL:            https://github.com/KhronosGroup/Vulkan-Headers
Source0:        https://github.com/KhronosGroup/Vulkan-Headers/archive/sdk-%{version}/%{uname}-sdk-%{version}.tar.xz
BuildRequires:  cmake


%description
Vulkan header files and API registry.

%prep
%autosetup -p1 -n %{uname}-sdk-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%{_includedir}/vulkan/
%{_includedir}/vk_video/
%dir %{_datadir}/vulkan
%{_datadir}/vulkan/registry/


%changelog
* Tue Oct 10 2023 tex - 1.3.231.1-1pclos2023
- Vulkan SDK 1.3.231.1
